@@ -1,4 +1,4 @@
-/* $Id: optimize.hpp 1664 2010-03-17 14:32:45Z bradbell $ */
+/* $Id: optimize.hpp 1661 2010-03-11 12:04:15Z bradbell $ */
 # ifndef CPPAD_OPTIMIZE_INCLUDED
 # define CPPAD_OPTIMIZE_INCLUDED
 
@@ -60,10 +60,9 @@ derivatives using the original operation sequence.
 $subhead Testing$$
 You can run the CppAD $cref/speed/speed_main/$$ tests and see
 the corresponding changes in number of variables and execution time.
-This will require that you specify the 
-$cref/--with-Speed/InstallUnix/--with-Speed/$$ option when you 
-configure CppAD.
-In this case, you can run the speed tests with optimization 
+After the $cref/make test/InstallUnix/make test/$$ command
+is run in the $code speed/cppad$$ directory,
+you can run the speed tests with optimization 
 using the command
 $codep
 	speed/cppad/cppad speed 123 optimize
@@ -127,12 +126,12 @@ $end
 */
 # include <stack>
 
+CPPAD_BEGIN_NAMESPACE
 /*!
 \file optimize.hpp
 Routines for optimizing a tape
 */
 
-CPPAD_BEGIN_NAMESPACE
 
 /*!
 State for this variable set during reverse sweep.
