@@ -15,12 +15,14 @@ var list_down1 = [
 'ad.xml',
 'adfun.xml',
 'library.xml',
+'cppad_ipopt_nlp.xml',
 'example.xml',
 'configure.xml',
 'appendix.xml'
 ];
 var list_down0 = [
 'installunix.xml',
+'pkgconfig.xml',
 'installwindows.xml'
 ];
 var list_current0 = [
