@@ -3,10 +3,11 @@
 // ------------------------------------------------------- 
 Keyword = 
 [
-"CppAD  cppad-20100101.4: A Package for Differentiation of C++ Algorithms   algorithmic automatic derivative version introduction include cppad.hpp symbol preprocessor namespace",
+"CppAD  cppad-20110101.3: A Package for Differentiation of C++ Algorithms   algorithmic automatic derivative version introduction include cppad.hpp symbol preprocessor namespace",
 "Install  CppAD Download, Test, and Installation Instructions  ",
-"InstallUnix  Unix Download, Test and Installation   cppad free fedora rpm cppad.spec tar file configure status return prefix directory documentation introduction get_started exp_apx example more speed double profile utility print forward mode std::vector postfix adolc fadbad sacado boost ipopt compile flags",
+"InstallUnix  Unix Download, Test and Installation   cppad free fedora rpm cppad.spec tar file configure get_started run exp_apx introduction example more testing speed check function utility profile print forward mode prefix directory documentation std::vector postfix adolc fadbad sacado boost ipopt compile flags",
 "subversion  Using Subversion To Download Source Code  ",
+"pkgconfig  CppAD pkg-config Files   pc",
 "InstallWindows  Windows Download and Test   free cppad zip file getstarted introduction example more print forward mode speed double utility",
 "Introduction  An Introduction by Example to Algorithmic Differentiation   ad automatic",
 "get_started.cpp  A Simple Program Using CppAD to Compute Derivatives   getstarted example",
@@ -149,7 +150,9 @@ Keyword =
 "reverse_one.cpp  First Order Reverse Mode: Example and Test  ",
 "reverse_two.cpp  Second Order Reverse ModeExample and Test  ",
 "HesTimesDir.cpp  Hessian Times Direction: Example and Test  ",
-"reverse_any.cpp  Any Order Reverse Mode: Example and Test  ",
+"reverse_three.cpp  Third Order Reverse Mode: Example and Test  ",
+"reverse_any.cpp  Reverse Mode General Case: Example and Test   composition",
+"checkpoint.cpp  Checkpoint and Function Composition: Example and Test  ",
 "Sparse  Calculating Sparsity Patterns  ",
 "ForSparseJac  Jacobian Sparsity Pattern: Forward Mode  ",
 "ForSparseJac.cpp  Forward Mode Jacobian Sparsity: Example and Test  ",
@@ -195,6 +198,8 @@ Keyword =
 "Near_Equal.cpp  NearEqual Function: Example and Test  ",
 "speed_test  Run One Speed Test and Return Results  ",
 "SpeedTest  Run One Speed Test and Print Results  ",
+"elapsed_seconds  Returns Elapsed Number of Seconds   time",
+"elapsed_seconds.cpp  Elapsed Seconds: Example and Test   timer",
 "speed_test.cpp  speed_test: Example and test  ",
 "speed_program.cpp  Example Use of SpeedTest  ",
 "NumericType  Definition of a Numeric Type   default constructor int copy exercise",
@@ -239,6 +244,8 @@ Keyword =
 "OdeGearControl.cpp  OdeGearControl: Example and Test  ",
 "BenderQuad  Computing Jacobian and Hessian of Bender's Reduced Objective  ",
 "BenderQuad.cpp  BenderQuad: Example and Test  ",
+"opt_val_hes  Jacobian and Hessian of Optimal Values  ",
+"opt_val_hes.cpp  opt_val_hes: Example and Test  ",
 "LuRatio  LU Factorization of A Square Matrix and Stability Calculation   linear equation determinant solve",
 "LuRatio.cpp  LuRatio: Example and Test  ",
 "std_math_unary  Float and Double Standard Math Unary Functions   abs acos asin atan cosh exp log log10 sinh sqrt tanh",
@@ -247,6 +254,19 @@ Keyword =
 "vectorBool.cpp  CppAD::vectorBool Class: Example and Test  ",
 "TrackNewDel  Routines That Track Use of New and Delete   memory openmp tracknewvec ndebug cppad_track_new_vec cppadtracknewvec trackdelvec cppad_track_del_vec cppadtrackdelvec trackextend cppad_track_extend cppadtrackextend trackcount cppad_track_count",
 "TrackNewDel.cpp  Tracking Use of New and Delete: Example and Test  ",
+"cppad_ipopt_nlp  Nonlinear Programming Using the CppAD Interface to Ipopt  ",
+"cppad_ipopt_windows  Linking the CppAD Interface to Ipopt in Visual Studio 9.0  ",
+"ipopt_get_started.cpp  Nonlinear Programming Using CppAD and Ipopt: Example and Test  ",
+"cppad_ipopt_ode  Example Simultaneous Solution of Forward and Inverse Problem  ",
+"ipopt_ode_problem  An ODE Inverse Problem Example  ",
+"ipopt_ode_simple  ODE Fitting Using Simple Representation   cppad_ipopt_nlp",
+"ipopt_ode_fast  ODE Fitting Using Fast Representation   cppad_ipopt_nlp",
+"ipopt_ode_problem.hpp  ODE Inverse Problem Definitions: Source Code   example",
+"ipopt_ode_simple.hpp  ODE Fitting Using Simple Representation   cppad_ipopt_nlp example source",
+"ipopt_ode_fast.hpp  ODE Fitting Using Fast Representation   cppad_ipopt_nlp example source",
+"ipopt_ode_run.hpp  Driver for Running the Ipopt ODE Example  ",
+"ipopt_ode_check.cpp  Correctness Check for Both Simple and Fast Representations  ",
+"ipopt_ode_speed.cpp  Speed Test for Both Simple and Fast Representations  ",
 "Example  Examples  ",
 "General  General Examples   realistic",
 "ExampleUtility  Utility Routines used by CppAD Examples  ",
@@ -255,19 +275,6 @@ Keyword =
 "ad_in_c.cpp  Example and Test Linking CppAD to Languages Other than C++   algorithmic differentiation automatic",
 "HesMinorDet.cpp  Gradient of Determinant Using Expansion by Minors: Example and Test  ",
 "HesLuDet.cpp  Gradient of Determinant Using LU Factorization: Example and Test  ",
-"ipopt_cppad_nlp  Nonlinear Programming Using the CppAD Interface to Ipopt  ",
-"ipopt_cppad_windows  Linking the CppAD Interface to Ipopt in Visual Studio 9.0  ",
-"ipopt_get_started.cpp  Nonlinear Programming Using CppAD and Ipopt: Example and Test  ",
-"ipopt_cppad_ode  Example Simultaneous Solution of Forward and Inverse Problem  ",
-"ipopt_ode_problem  An ODE Inverse Problem Example  ",
-"ipopt_ode_simple  ODE Fitting Using Simple Representation   ipopt_cppad_nlp",
-"ipopt_ode_fast  ODE Fitting Using Fast Representation   ipopt_cppad_nlp",
-"ipopt_ode_problem.hpp  ODE Inverse Problem Definitions: Source Code   example",
-"ipopt_ode_simple.hpp  ODE Fitting Using Simple Representation   ipopt_cppad_nlp example source",
-"ipopt_ode_fast.hpp  ODE Fitting Using Fast Representation   ipopt_cppad_nlp example source",
-"ipopt_ode_run.hpp  Driver for Running the Ipopt ODE Example  ",
-"ipopt_ode_check.cpp  Correctness Check for Both Simple and Fast Representations  ",
-"ipopt_ode_speed.cpp  Speed Test for Both Simple and Fast Representations  ",
 "Interface2C.cpp  Interfacing to C: Example and Test   difference central",
 "JacMinorDet.cpp  Gradient of Determinant Using Expansion by Minors: Example and Test  ",
 "JacLuDet.cpp  Gradient of Determinant Using Lu Factorization: Example and Test  ",
@@ -289,10 +296,11 @@ Keyword =
 "speed_main  Speed Testing Main Program   cppad uniform_01",
 "link_det_lu  Speed Testing Gradient of Determinant Using Lu Factorization  ",
 "link_det_minor  Speed Testing Gradient of Determinant by Minor Expansion  ",
+"link_ode  Speed Testing the Jacobian of Ode Solution  ",
 "link_poly  Speed Testing Second Derivative of a Polynomial  ",
 "link_sparse_hessian  Speed Testing Sparse Hessian  ",
 "link_sparse_jacobian  Speed Testing Sparse Jacobian  ",
-"link_ode  Speed Testing the Jacobian of Ode Solution  ",
+"microsoft_timer  Microsoft Version of Elapsed Number of Seconds  ",
 "speed_utility  Speed Testing Utilities  ",
 "uniform_01  Simulate a [0,1] Uniform Random Variate   vector",
 "uniform_01.hpp  Source: uniform_01  ",
@@ -371,8 +379,9 @@ Keyword =
 "glossary  Glossary   ad function of base levels above type elementary vector operation atomic sequence dependent independent parameter sparsity pattern efficient boolean sets tape active inactive variable variables taylor coefficient",
 "Bib  Bibliography  ",
 "Bugs  Know Bugs and Problems Using CppAD   gcc 3.4.4",
-"WishList  The CppAD Wish List   new features atan2 condexp sequence operation optimize tape operations",
+"WishList  The CppAD Wish List   new features atan2 condexp sequence operation",
 "whats_new  Changes and Additions to CppAD  ",
+"whats_new_10  Changes and Additions to CppAD During 2010  ",
 "whats_new_09  Changes and Additions to CppAD During 2009  ",
 "whats_new_08  Changes and Additions to CppAD During 2008   erf ipopt_cppad_nlp",
 "whats_new_07  Changes and Additions to CppAD During 2007  ",
